@@ -1,4 +1,4 @@
-## Copyright (C) 2008-2018 Jaroslav Hajek <highegg@gmail.com>
+## Copyright (C) 2008-2020 Jaroslav Hajek <highegg@gmail.com>
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -31,7 +31,7 @@
 ##
 ## @var{aspec} is a combination of letters r,w,x, corresponding
 ## to queried access privileges to the file. The query is true
-## if the current user has all the spefied types of access, either
+## if the current user has all the specified types of access, either
 ## through "user", "group" or "other" specs.
 ##
 ## @seealso{stat, lstat}
@@ -48,15 +48,15 @@ else
     for c = tspec
       switch (c)
       case 'f'
-	ft |= S_ISREG (s.mode);
+        ft |= S_ISREG (s.mode);
       case 'd'
-	ft |= S_ISDIR (s.mode);
+        ft |= S_ISDIR (s.mode);
       case 'p'
-	ft |= S_ISFIFO (s.mode);
+        ft |= S_ISFIFO (s.mode);
       case 'S'
-	ft |= S_ISSOCK (s.mode);
+        ft |= S_ISSOCK (s.mode);
       otherwise
-	error ("invalid file type spec: %s", c)
+        error ("fexist: invalid file type spec: %s", c)
       endswitch
     endfor
     ex &= ft;
@@ -69,13 +69,13 @@ else
     for c = aspec
       switch (c)
       case 'r'
-	at &= (mypid && mstr(1) == c) || (mygid && mstr(4) == c) || mstr(7) == c;
+        at &= (mypid && mstr(1) == c) || (mygid && mstr(4) == c) || mstr(7) == c;
       case 'w'
-	at &= (mypid && mstr(2) == c) || (mygid && mstr(5) == c) || mstr(8) == c;
+        at &= (mypid && mstr(2) == c) || (mygid && mstr(5) == c) || mstr(8) == c;
       case 'x'
-	at &= (mypid && mstr(3) == c) || (mygid && mstr(6) == c) || mstr(9) == c;
+        at &= (mypid && mstr(3) == c) || (mygid && mstr(6) == c) || mstr(9) == c;
       otherwise
-	error ("invalid access type spec: %s", c)
+        error ("fexist: invalid access type spec: %s", c)
       endswitch
     endfor
     ex &= at;
