@@ -1,4 +1,4 @@
-## Copyright (C) 2012-2017 Philip Nienhuis
+## Copyright (C) 2012-2020 Philip Nienhuis
 ## 
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ function [sh_names, fformat] = __JXL_spsh_info__ (xls)
   if (sh_cnt > 0)
     fformat = "xlWorkbookNormal";
   else
-    fformat = '';
+    fformat = "";
   endif
 
 endfunction
