@@ -1,5 +1,5 @@
-## Copyright (C) 2013-2019 Markus Bergholz
-## Parts Copyright (C) 2014-2019 Philip Nienhuis
+## Copyright (C) 2013-2020 Markus Bergholz
+## Parts Copyright (C) 2014-2020 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -44,7 +44,7 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
 
   elseif (ischar (wsh))
     if (length (wsh) > 31)
-      error ("Worksheet name longer than 31 characters is not supported by Excel\n");
+      error ("oct2xls: worksheet name longer than 31 characters is not supported by Excel\n");
     endif
     wsh_number = find (strcmp (wsh, xls.sheets.sh_names));
     if (isempty (wsh_number))
@@ -248,7 +248,10 @@ function [xls, rstatus] = __OCT_oct2xlsx__ (arrdat, xls, wsh, crange="", spsh_op
     ## when writing data to existing worksheets, MS-Excel might complain about
     ## xl/calcChain.xml. As MS-Excel will regenerate it and only MS-Excel ever
     ## uses it, the easiest thing is to just delete the file from the archive.
-    unlink ([xls.workbook filesep "xl" filesep "calcChain.xml"]);
+    try
+      unlink ([xls.workbook filesep "xl" filesep "calcChain.xml"]);
+    catch
+    end_try_catch
   
   endif
 
