@@ -1,4 +1,4 @@
-## Copyright (C) 2011-2019 Philip Nienhuis
+## Copyright (C) 2011-2020 Philip Nienhuis
 ##
 ## This program is free software; you can redistribute it and/or modify it under
 ## the terms of the GNU General Public License as published by the Free Software
@@ -57,7 +57,7 @@ function [ xls, rstatus ] = __UNO_oct2spsh__ (c_arr, xls, wsh, crange, spsh_opts
     ## FIXME sheet capacity check needed
     if (isnumeric (wsh))
       if (wsh < 1)
-        error ("Illegal sheet index: %d", wsh);
+        error ("oct2xls: illegal sheet index: %d", wsh);
       elseif (wsh > numel (sh_names))
         ## New sheet to be added. First create sheet name but check if it already exists
         shname = sprintf ("Sheet%d", numel (sh_names) + 1);
@@ -74,7 +74,7 @@ function [ xls, rstatus ] = __UNO_oct2spsh__ (c_arr, xls, wsh, crange, spsh_opts
             endif
           endwhile
           if (ii > maxtry + 1)
-            error ("Could not add sheet with a unique name to file %s");
+            error ("oct2xls: couldn't add sheet with a unique name to file %s");
           endif
         endif
         wsh = shname;
@@ -106,12 +106,12 @@ function [ xls, rstatus ] = __UNO_oct2spsh__ (c_arr, xls, wsh, crange, spsh_opts
                       spsh_chkrange (crange, nr, nc, xls.xtype, xls.filename);
   --trow; --lcol;               ## Zero-based row ## & col ##
   if (nrows < nr || ncols < nc)
-    warning ("Array truncated to fit in range\n");
+    warning ("oct2xls: array truncated to fit in range\n");
     c_arr = c_arr(1:nrows, 1:ncols);
   endif
-	
+
   ## Parse data array, setup typarr and throw out NaNs  to speed up writing;
-  typearr = spsh_prstype (c_arr, nrows, ncols, ctype, spsh_opts, 0);
+  typearr = spsh_prstype (c_arr, nrows, ncols, ctype, spsh_opts);
   if ~(spsh_opts.formulas_as_text)
     ## Find formulas (designated by a string starting with "=" and ending in ")")
     fptr = cellfun (@(x) ischar (x) && strncmp (x, "=", 1), c_arr);
@@ -141,15 +141,15 @@ function [ xls, rstatus ] = __UNO_oct2spsh__ (c_arr, xls, wsh, crange, spsh_opts
           otherwise
             ## Empty cell
         endswitch
-		    changed = 1;
+        changed = 1;
       catch
-        printf ("Error writing cell %s (typearr() = %d)\n",...
+        printf ("oct2xls: error writing cell %s (typearr() = %d)\n",...
                 calccelladdress(trow+ii, lcol+jj), typearr(ii, jj));
-		  end_try_catch
+      end_try_catch
     endfor
   endfor
 
-  if (changed)	
+  if (changed)
     ## Preserve 2 (new file), 1 (existing)
     xls.changed = max (min (xls.changed, 2), changed);
     rstatus = 1;
