@@ -1,5 +1,5 @@
-// Copyright (C) 2004-2019 Laurent Mazet <mazet@crm.mot.com>
-// Copyright (C) 2016-2019 Philip Nienhuis <prnienhuis@users.sf.net>  
+// Copyright (C) 2004-2020 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2016-2020 Philip Nienhuis <prnienhuis@users.sf.net>  
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -55,7 +55,7 @@
 #include <octave/oct.h>
 #include <octave/Cell.h>
 
-#include "config.h"
+#include "octave_4_2_compatibility.h"
 
 DEFUN_DLD (cell2csv, args, nargout,
           "-*- texinfo -*-\n"
@@ -135,7 +135,7 @@ DEFUN_DLD (cell2csv, args, nargout,
         word += str;
       }
 
-      else if (!c(i, j).OV_ISEMPTY ()) {
+      else if (!c(i, j).isempty ()) {
         /* Output NaN value */
         warning ("cell2csv: empty cell or not a real or a string value - converted to 'NaN'\n");
         word += "NaN";
