@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2016 Philip Nienhuis
+// Copyright (C) 2014-2020 Philip Nienhuis
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -13,13 +13,47 @@
 // You should have received a copy of the GNU General Public License along with
 // this program; if not, see <http://www.gnu.org/licenses/>.
 
+/*
+
+%% Test simple case
+%!test
+%! assert (col2num ("a"), 1, 1e-16);
+%!test
+%! assert (col2num ("z"), 26, 1e-16);
+
+%% Test more complicated string
+%!test
+%! assert (col2num ("aa"), 27, 1e-16);
+%!test
+assert (col2num ("ydf"), 17010, 1e-16);
+
+%% Test case insensitivity
+%!test
+%! assert (col2num ("A"), 1, 1e-16);
+%!test
+assert (col2num ("Ydf"), 17010, 1e-16);
+%!test
+assert (col2num ("yDf"), 17010, 1e-16);
+%!test
+assert (col2num ("ydF"), 17010, 1e-16);
+%!test
+assert (col2num ("YDf"), 17010, 1e-16);
+%!test
+assert (col2num ("yDF"), 17010, 1e-16);
+%!test
+assert (col2num ("YdF"), 17010, 1e-16);
+%!test
+assert (col2num ("YDF"), 17010, 1e-16);
+
+*/
+
 #include <octave/oct.h>
 
 DEFUN_DLD (col2num, args, nargout, 
           "-*- texinfo -*-\n"
           "@deftypefn {Loadable Function} {@var{N} = } col2num (@var{CIDX})\n"
        "\n"
-       "Convert a spreadsheet column Id into a numerical column number. "
+       "Convert a spreadsheet column Id into a numerical column number."
        "@end deftypefn") {
 
   /* Get arguments */
