@@ -1,5 +1,5 @@
-// Copyright (C) 2004-2019 Laurent Mazet <mazet@crm.mot.com>
-// Copyright (C) 2014-2019 Philip Nienhuis <prnienhuis@users.sf.net>
+// Copyright (C) 2004-2020 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2014-2020 Philip Nienhuis <prnienhuis@users.sf.net>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -188,9 +188,9 @@
 #include <octave/ov.h>
 #include <octave/file-ops.h>
 
-#include "config.h"
+#include "octave_4_2_compatibility.h"
 
-#define MAXSTRINGLENGTH 4096
+#define MAXSTRINGLENGTH 32768
 
 DEFUN_DLD (csv2cell, args, nargout, 
           "-*- texinfo -*-\n\
@@ -212,7 +212,7 @@ a string. The default is a double quote (@code{\"}).\n\
 Optional argument @var{hl} (a numeric value >= 0) is the number of \
 headerlines to skip; negative values are ignored. If @var{hl} is \
 equal to or larger than the total number of lines in the file, no \
-data are read and an empty cell array is returned.\n\
+data is read and an empty cell array is returned.\n\
 \n\
 Alternatively, optional argument @var{range} can be specified as a \
 spreadsheet-style cell range to specify a block of fields to be \
@@ -232,10 +232,10 @@ line.\n\
 Note: newline characters in fields (i.e., multi-line text fields) are not \
 allowed.\n\
 \n\
-The maximum line width of the csv file is set to 4096 characters.\n\
-(This is also the theoretical maximum number of columns in the data \n\
-if all fields are empty, i.e., a line containing just 4096 consecutive \n\
-separators.)\n\
+The maximum line width of the csv file is set to 32768 characters.\n\
+(This is also the theoretical maximum number of columns - 1 in the data \n\
+if all fields are empty, i.e., a line containing just 32768 consecutive \n\
+separators will yield 32769 empty values.)\n\
 @end deftypefn") {
 
   /* Get arguments */
@@ -250,8 +250,8 @@ separators.)\n\
   const std::string file = octave::sys::file_ops::tilde_expand (args (0).string_value ());
 
   /* Look if first arg after filename = numeric. If yes => headerlines */
-  long hlines = (nargin > 1 && args(1).OV_ISNUMERIC () ? args(1).long_value() : 0);
-  int arg_sh = (nargin > 1 && args(1).OV_ISNUMERIC () ? 1 : 0);
+  long hlines = (nargin > 1 && args(1).isnumeric () ? args(1).long_value() : 0);
+  int arg_sh = (nargin > 1 && args(1).isnumeric () ? 1 : 0);
 
   bool lr = false;
   int lcol = 1;
