@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2019 Laurent Mazet <mazet@crm.mot.com>
+// Copyright (C) 2004-2020 Laurent Mazet <mazet@crm.mot.com>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -16,7 +16,7 @@
 #include <octave/oct.h>
 #include <octave/Cell.h>
 
-#include "config.h"
+#include "octave_4_2_compatibility.h"
 
 DEFUN_DLD (csvexplode, args, nargout,
            "-*- texinfo -*-\n"
@@ -38,7 +38,7 @@ DEFUN_DLD (csvexplode, args, nargout,
 
   /* Get arguments */
   if (! args(0).is_string ()) {
-    if (args(0).OV_ISCELL ())
+    if (args(0).iscell ())
       return octave_value (args(0));
     else
       return octave_value (Cell(args(0)));
